@@ -2,7 +2,7 @@
 # pylint: disable=expression-not-assigned,line-too-long,missing-module-docstring
 import sys
 
-from gelee.cli import main
+from gelee.cli import app
 
-if __name__ == "__main__":
-    sys.exit(main(sys.argv[1:]))  # pragma: no cover
+if __name__ == '__main__':
+    sys.exit(app(prog_name='gelee'))  # pragma: no cover
